pauseTimer method
void
pauseTimer()
Pauses the countdown timer.
You can later resume the timer by calling resumeTimer.
Implementation
void pauseTimer() {
_timer?.cancel();
notifyListeners();
}
Pauses the countdown timer.
You can later resume the timer by calling resumeTimer.
void pauseTimer() {
_timer?.cancel();
notifyListeners();
}